import{u as s}from"./icons.da02f7f7.js";import{d as r,a as c,b as d,er as i,f as _,u as l,b0 as u,v as f}from"./registerWidgets.4340e287.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="6ae10adc-67c2-4425-9489-f7d501e4ada6",e._sentryDebugIdIdentifier="sentry-dbid-6ae10adc-67c2-4425-9489-f7d501e4ada6")}catch{}})();const p=r({__name:"BackButton",emits:["exitFullscreenPreview"],setup(e,{emit:t}){return(a,n)=>{const o=c("icon");return d(),i("button",{class:"back-btn",onClick:n[0]||(n[0]=b=>t("exitFullscreenPreview"))},[_(o,{class:"icon",path:l(s),width:"20",height:"20",fill:"#5A677A"},null,8,["path"]),u(" Editor ")])}}});const v=f(p,[["__scopeId","data-v-eaeb3a6e"]]);export{v as B};
//# sourceMappingURL=BackButton.fbd499db.js.map
