import{P as r}from"./Passwordless.81090626.js";import{d as a,ex as d,b as i,er as c,f as s,w as _,v as m}from"./registerWidgets.4340e287.js";import{M as f}from"./member.02e55f2a.js";import{W as p}from"./WidgetsFrame.0a348048.js";import"./CircularLoading.1cc5445b.js";import"./icons.da02f7f7.js";import"./passwordlessManager.8c70219b.js";import"./pubsub.3290d859.js";import"./storage.dfe55847.js";import"./gateway.1f2ccdb0.js";import"./activeRecord.c40ac301.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="2a59bd23-442d-4bfa-a6b5-5e688512c8b6",e._sentryDebugIdIdentifier="sentry-dbid-2a59bd23-442d-4bfa-a6b5-5e688512c8b6")}catch{}})();const l={class:"login"},u=a({__name:"Login",setup(e){const o=d();async function t(n){await f.login(),o.push({name:"home"})}return(n,b)=>(i(),c("div",l,[s(p,{theme:"white","main-color":"#d14056","font-family":"sans-serif",runtime:"dash"},{default:_(()=>[s(r,{class:"passwordless",onDone:t})]),_:1})]))}});const B=m(u,[["__scopeId","data-v-0e3dc783"]]);export{B as default};
//# sourceMappingURL=Login.5e594c01.js.map
