import{v as t,b as s,er as c}from"./registerWidgets.4340e287.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="ee5771dc-8ceb-409c-af65-e5de0f2345ca",e._sentryDebugIdIdentifier="sentry-dbid-ee5771dc-8ceb-409c-af65-e5de0f2345ca")}catch{}})();const r={},o={class:"organization-settings"};function a(e,n){return s(),c("div",o,"Organization settings")}const f=t(r,[["render",a]]);export{f as default};
//# sourceMappingURL=OrganizationSettings.b779f9a7.js.map
