import{d as g,ex as v,ey as k,r as b,b as r,c as s,w as a,u as e,f as u,eu as i}from"./registerWidgets.4340e287.js";import{S as j,L as w}from"./SmartConsole.a2b6bdb5.js";import{a as I}from"./asyncComputed.a4cc4ebe.js";import{J as x}from"./jobs.33e9ced7.js";import{_ as B}from"./SaveButton.vue_vue_type_script_setup_true_lang.a60de054.js";import{_ as C}from"./DocsButton.vue_vue_type_script_setup_true_lang.82d53ed3.js";import{B as S}from"./BaseLayout.6b4d6782.js";import{_ as T,a as D}from"./JobSettings.vue_vue_type_script_setup_true_lang.b38f3760.js";import{c as R}from"./index.87d21376.js";import{A as _,T as $}from"./TabPane.629b28d9.js";import"./forms.35e1ba4a.js";import"./activeRecord.c40ac301.js";import"./pubsub.3290d859.js";import"./dashes.8416a46d.js";import"./index.bdeb3c9e.js";import"./hooks.d572fc44.js";import"./workspaces.ff4ec9b2.js";import"./icons.da02f7f7.js";import"./Title.4165770a.js";import"./index.d24f6130.js";import"./uuid.3f26f6c2.js";import"./storage.dfe55847.js";import"./ant-design.56df7a71.js";import"./dayjs.a93d12f0.js";import"./index.17a2edf7.js";import"./Form.7b78c348.js";import"./index.c13b703c.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},m=new Error().stack;m&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[m]="e4f3cf06-0adc-4215-9302-ca887b36362c",n._sentryDebugIdIdentifier="sentry-dbid-e4f3cf06-0adc-4215-9302-ca887b36362c")}catch{}})();const ne=g({__name:"JobEditor",setup(n){const m=v(),l=k(),f=b(null),o=b("test");function y(){m.push({name:"jobs"})}const{result:t}=I(()=>x.get(l.params.jobId)),p=w.create();return(A,d)=>(r(),s(S,null,{navbar:a(()=>[e(t)?(r(),s(e(R),{key:0,title:e(t).title,onBack:y},{footer:a(()=>[u(e($),{"active-key":o.value,"onUpdate:activeKey":d[0]||(d[0]=c=>o.value=c)},{default:a(()=>[u(e(_),{key:"test",tab:"Test"}),u(e(_),{key:"settings",tab:"Settings"})]),_:1},8,["active-key"])]),extra:a(()=>[u(C),o.value==="settings"?(r(),s(B,{key:0,model:e(t)},null,8,["model"])):i("",!0)]),_:1},8,["title"])):i("",!0)]),content:a(()=>[e(t)&&o.value==="test"?(r(),s(T,{key:0,ref_key:"tester",ref:f,job:e(t),"log-service":e(p)},null,8,["job","log-service"])):i("",!0),e(t)&&o.value==="settings"?(r(),s(D,{key:1,job:e(t)},null,8,["job"])):i("",!0)]),footer:a(()=>{var c;return[e(t)&&o.value==="test"?(r(),s(j,{key:0,runtime:"forms","log-service":e(p),onRestart:(c=f.value)==null?void 0:c.test},null,8,["log-service","onRestart"])):i("",!0)]}),_:1}))}});export{ne as default};
//# sourceMappingURL=JobEditor.5c8bf3ae.js.map
