import{S as p}from"./Sidebar.91ceeca2.js";import{_ as c}from"./Navbar.vue_vue_type_script_setup_true_lang.9256bd68.js";import{F as l,G as u,H as b}from"./icons.da02f7f7.js";import{d,ey as f,H as g,a as _,b as y,c as v,w as t,f as r}from"./registerWidgets.4340e287.js";import{a as w}from"./asyncComputed.a4cc4ebe.js";import"./gateway.1f2ccdb0.js";import{O as z}from"./organization.9c2e4599.js";import"./index.dbce76fa.js";import{B as h}from"./BaseLayout.6b4d6782.js";import"./Tooltip.595c175f.js";import"./logo.084e5d7c.js";import"./passwordlessManager.8c70219b.js";import"./pubsub.3290d859.js";import"./storage.dfe55847.js";import"./index.f58e2ef8.js";import"./Title.4165770a.js";import"./index.c13b703c.js";import"./index.87d21376.js";import"./activeRecord.c40ac301.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="725b19f2-eff1-43e3-8926-3bb838994046",e._sentryDebugIdIdentifier="sentry-dbid-725b19f2-eff1-43e3-8926-3bb838994046")}catch{}})();const A=d({__name:"Organization",setup(e){const n=f().params.organizationId,{result:a}=w(()=>z.get(n)),i=g(()=>a.value?[{label:"My organizations",path:"/organizations"},{label:a.value.name,path:`/organizations/${a.value.id}`}]:void 0),s=[{name:"Organization",items:[{name:"Projects",icon:l,path:"projects"},{name:"Members",icon:u,path:"members"},{name:"Billing",icon:b,path:"billing",unavailable:!0}]}];return(I,B)=>{const m=_("router-view");return y(),v(h,null,{navbar:t(()=>[r(c,{breadcrumb:i.value},null,8,["breadcrumb"])]),sidebar:t(()=>[r(p,{class:"sidebar",sections:s})]),content:t(()=>[r(m)]),_:1})}}});export{A as default};
//# sourceMappingURL=Organization.a8cc97c6.js.map
