import{v as r,a,b as i,c,g as p,h as d,_,i as u,l,T as h,P as f,C as b,M as g,s as y,j as m,k as s,m as v,n as w,p as k}from"./registerWidgets.4340e287.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="ee693941-41b6-4507-8064-adbf817764ee",e._sentryDebugIdIdentifier="sentry-dbid-ee693941-41b6-4507-8064-adbf817764ee")}catch{}})();const I={};function A(e,t){const n=a("router-view");return i(),c(n,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const x=r(I,[["render",A]]),o=p({history:d("/"),routes:[{path:"/:path(.*)*",name:"player",component:()=>_(()=>import("./Player.0ebf3d0f.js"),["assets/Player.0ebf3d0f.js","assets/index.bdeb3c9e.js","assets/registerWidgets.4340e287.js","assets/registerWidgets.8ce475af.css","assets/uuid.3f26f6c2.js","assets/broker.439256b4.js","assets/passwordlessManager.8c70219b.js","assets/pubsub.3290d859.js","assets/storage.dfe55847.js","assets/Passwordless.81090626.js","assets/CircularLoading.1cc5445b.js","assets/CircularLoading.f81b57b4.css","assets/icons.da02f7f7.js","assets/Passwordless.38735f5c.css","assets/executeJs.cdd93f83.js","assets/PlayerNavbar.c59d454a.js","assets/PlayerNavbar.76a7eb2f.css","assets/Steps.36594e67.js","assets/Steps.998aa76d.css","assets/Modal.51841735.js","assets/Modal.5aaf8eba.css","assets/executeJs.887e9a58.css","assets/WidgetsFrame.0a348048.js","assets/WidgetsFrame.0816a5f5.css","assets/ActionButton.vue_vue_type_script_setup_true_lang.9db638e5.js","assets/broker.fcc295cc.css","assets/DashPlayer.e7cd0390.js","assets/geometryUtils.7de327f5.js","assets/DashPlayer.4868beea.css","assets/asyncComputed.a4cc4ebe.js","assets/Player.77337a17.css"])}],scrollBehavior(e){if(e.hash)return{el:e.hash}}});class D{static init(){setInterval(()=>fetch("/_healthcheck"),20*1e3)}}const W=()=>{const e=u({render:()=>l(x)});h.init(),D.init(),e.use(o),e.use(f),e.mount("#app"),e.component("VSelect",b),e.component("Markdown",g),e.component("Message",y),m(e,o),s(e,v),s(e,w),s(e,k)};W();
//# sourceMappingURL=player.9c288617.js.map
