import{M as r}from"./Modal.51841735.js";import{d as a,G as d,r as c,a as _,b as f,er as l,f as n,w as i,bu as u,e as m,v as p}from"./registerWidgets.4340e287.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="b7976d9d-9195-47e4-a3db-7ff52502141c",e._sentryDebugIdIdentifier="sentry-dbid-b7976d9d-9195-47e4-a3db-7ff52502141c")}catch{}})();const b=["src"],y=a({__name:"Home",setup(e){const o=d({onboardingForm:""}),t=c(null);return(g,v)=>{const s=_("router-view");return f(),l(u,null,[n(s,{class:"router"}),n(r,{ref_key:"modal",ref:t},{content:i(()=>[m("iframe",{class:"form",src:o.onboardingForm},null,8,b)]),_:1},512)],64)}}});const x=p(y,[["__scopeId","data-v-7e290e34"]]);export{x as default};
//# sourceMappingURL=Home.6eb1af12.js.map
