html,body{overscroll-behavior-x:none}.workflow-editor[data-v-b6d02a33]{display:flex;flex-direction:column}.workflow-editor .title[data-v-b6d02a33]{display:flex;align-items:center;gap:10px}.workflow-editor .title:not(:hover) .edit-icon[data-v-b6d02a33]{display:none}.workflow-editor .title .edit-icon[data-v-b6d02a33]{cursor:pointer}.workflow-editor .workflow-editor-content[data-v-b6d02a33]{display:flex;flex-grow:1}.workflow-editor .workflow-editor-content .workflow-toolbar[data-v-b6d02a33]{display:flex;flex-direction:column;background-color:#fff;gap:10px;padding:10px;box-shadow:0 0 5px #0003}.workflow-editor .workflow-editor-content .workflow-toolbar .toolbar-item[data-v-b6d02a33]{cursor:grab}.workflow-editor .workflow-editor-content .workflow-toolbar .toolbar-item[data-v-b6d02a33]:hover{box-shadow:0 0 5px #0003;transform:rotate(-5deg)}.workflow-editor .canvas-container[data-v-b6d02a33]{flex-grow:1;flex-basis:0;position:relative;overflow:auto;outline:none}.workflow-editor .canvas-container[data-v-b6d02a33]:focus{border:2px solid #ebebeb}.workflow-editor .canvas-container .workflow-canvas[data-v-b6d02a33]{position:absolute;top:0;left:0;width:100%;height:100%;user-select:none;background-color:#fbfbfb}
