import{d,ey as b,H as m,a as g,b as f,c as v,w as i,f as s}from"./registerWidgets.4340e287.js";import{B as _}from"./BaseLayout.6b4d6782.js";import{a as y}from"./asyncComputed.a4cc4ebe.js";import{P as h}from"./project.9f1727ca.js";import"./gateway.1f2ccdb0.js";import{O as z}from"./organization.9c2e4599.js";import"./index.dbce76fa.js";import{_ as j}from"./Navbar.vue_vue_type_script_setup_true_lang.9256bd68.js";import{S as I}from"./Sidebar.91ceeca2.js";import{I as w,J as k,K as B,L as P,M as $,N as C,O as M,F as x,G as D,H as L}from"./icons.da02f7f7.js";import"./activeRecord.c40ac301.js";import"./pubsub.3290d859.js";import"./passwordlessManager.8c70219b.js";import"./storage.dfe55847.js";import"./logo.084e5d7c.js";import"./index.f58e2ef8.js";import"./Title.4165770a.js";import"./index.c13b703c.js";import"./index.87d21376.js";import"./Tooltip.595c175f.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="7f7758ee-35e3-43e6-b148-66b08d74e6b6",o._sentryDebugIdIdentifier="sentry-dbid-7f7758ee-35e3-43e6-b148-66b08d74e6b6")}catch{}})();const ee=d({__name:"Project",setup(o){const c=b().params.projectId,{result:e}=y(()=>h.get(c).then(async a=>{const t=await z.get(a.organizationId);return{project:a,organization:t}})),l=m(()=>{var a,t,n,p;return((a=e.value)==null?void 0:a.organization)&&e.value.project?[{label:"My organizations",path:"/organizations"},{label:(n=(t=e.value)==null?void 0:t.organization)==null?void 0:n.name,path:`/organizations/${(p=e.value)==null?void 0:p.organization.id}`},{label:e.value.project.name,path:`/projects/${e.value.project.id}`}]:void 0}),u=m(()=>{var a;return(a=e.value)!=null&&a.project?[{name:"Project",items:[{name:"Builds",path:"builds",icon:w},{name:"Connectors",path:"connectors",icon:k},{name:"Tables",path:"tables",icon:B},{name:"API Keys",path:"api-keys",icon:P},{name:"Env Vars",path:"env-vars",icon:$},{name:"Logs",icon:C,path:"logs",beta:!0},{name:"Settings",icon:M,path:"settings"}]},{name:"Organization",items:[{name:"Projects",icon:x,path:`/organizations/${e.value.project.organizationId}/projects`},{name:"Members",icon:D,path:`/organizations/${e.value.project.organizationId}/members`},{name:"Billing",icon:L,path:`/organizations/${e.value.project.organizationId}/billing`,unavailable:!0}]}]:[]});return(a,t)=>{const n=g("router-view");return f(),v(_,null,{content:i(()=>[s(n)]),navbar:i(()=>[s(j,{class:"nav",breadcrumb:l.value},null,8,["breadcrumb"])]),sidebar:i(()=>[s(I,{class:"sidebar",sections:u.value},null,8,["sections"])]),_:1})}}});export{ee as default};
//# sourceMappingURL=Project.f83f6047.js.map
