import{d,r as i,o as c,eN as l,b as f,er as u,eA as p,eL as y}from"./registerWidgets.4340e287.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="063aa49c-acd3-4045-abdc-3f8aea822f33",e._sentryDebugIdIdentifier="sentry-dbid-063aa49c-acd3-4045-abdc-3f8aea822f33")}catch{}})();const m=d({__name:"ActionButton",props:{action:{},displayName:{}},emits:["click"],setup(e,{emit:n}){const a=e,o=i(null);return c(()=>{o.value&&a.action.setElement(o.value),l.addAction(a.action)}),(s,t)=>(f(),u("button",{ref_key:"element",ref:o,class:"next-button",onClick:t[0]||(t[0]=r=>n("click")),onKeydown:t[1]||(t[1]=y(r=>n("click"),["enter"]))},p(s.displayName),545))}});export{m as _};
//# sourceMappingURL=ActionButton.vue_vue_type_script_setup_true_lang.9db638e5.js.map
