import{d as y,es as b,G as _,b as l,er as c,e as i,u as v,et as a,aL as f,eu as m,ev as S,ew as g,v as k}from"./registerWidgets.4340e287.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="f49b72ee-884b-41fc-b0f9-b69f35982b7f",e._sentryDebugIdIdentifier="sentry-dbid-f49b72ee-884b-41fc-b0f9-b69f35982b7f")}catch{}})();const w=y({__name:"Modal",props:{containerStyle:{},headerStyle:{},contentStyle:{}},emits:["open","close"],setup(e,{expose:t,emit:n}){const p=b(),u=()=>{o.isOpened=!0,n("open")},r=()=>{o.isOpened=!1,n("close")};t({open:u,close:r});const o=_({isOpened:!1});return(s,d)=>(l(),c("div",{class:g(["background",o.isOpened&&"visible"]),onClick:r},[i("div",{class:"container",style:a(s.containerStyle),onClick:d[0]||(d[0]=S(()=>{},["stop"]))},[v(p).header?(l(),c("div",{key:0,class:"header",style:a(s.headerStyle)},[f(s.$slots,"header",{},void 0,!0)],4)):m("",!0),i("div",{class:"content",style:a(s.contentStyle)},[f(s.$slots,"content",{},void 0,!0)],4)],4)],2))}});const I=k(w,[["__scopeId","data-v-24f739ca"]]);export{I as M};
//# sourceMappingURL=Modal.51841735.js.map
