import"./registerWidgets.4340e287.js";import{M as r}from"./Title.4165770a.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="6955c911-c076-4a85-84a4-8fe83523cf8f",e._sentryDebugIdIdentifier="sentry-dbid-6955c911-c076-4a85-84a4-8fe83523cf8f")}catch{}})();function f(e){switch(typeof e){case"object":return Object.entries(e).map(([t,n])=>({title:t,key:t,children:f(n)}));default:return[{title:e,key:e}]}}function c(e){return new Promise(t=>{r.confirm({title:e,onOk:()=>t(!0),onCancel:()=>t(!1)})})}export{c as a,f as t};
//# sourceMappingURL=ant-design.56df7a71.js.map
