import{d as b,ex as g,ey as v,r as k,b as r,c as a,w as s,u as e,f as l,eu as i}from"./registerWidgets.4340e287.js";import{S as h,L as w}from"./SmartConsole.a2b6bdb5.js";import{a as x}from"./asyncComputed.a4cc4ebe.js";import{H as B}from"./hooks.d572fc44.js";import{_ as C}from"./SaveButton.vue_vue_type_script_setup_true_lang.a60de054.js";import{_ as H}from"./DocsButton.vue_vue_type_script_setup_true_lang.82d53ed3.js";import{B as I}from"./BaseLayout.6b4d6782.js";import{_ as S,a as T}from"./HookSettings.vue_vue_type_script_setup_true_lang.f25a8521.js";import{c as D}from"./index.87d21376.js";import{A as _,T as R}from"./TabPane.629b28d9.js";import"./forms.35e1ba4a.js";import"./activeRecord.c40ac301.js";import"./pubsub.3290d859.js";import"./dashes.8416a46d.js";import"./index.bdeb3c9e.js";import"./jobs.33e9ced7.js";import"./workspaces.ff4ec9b2.js";import"./icons.da02f7f7.js";import"./Title.4165770a.js";import"./index.d24f6130.js";import"./uuid.3f26f6c2.js";import"./storage.dfe55847.js";import"./ant-design.56df7a71.js";import"./index.7512814c.js";import"./index.c13b703c.js";import"./index.9aade351.js";import"./index.17a2edf7.js";import"./Form.7b78c348.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},m=new Error().stack;m&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[m]="0d177131-97b5-41e4-97aa-b0a05c64d92b",n._sentryDebugIdIdentifier="sentry-dbid-0d177131-97b5-41e4-97aa-b0a05c64d92b")}catch{}})();const ie=b({__name:"HookEditor",setup(n){const m=g(),p=v(),c=k(null),o=k("test");function y(){m.push({name:"hooks"})}const{result:t}=x(()=>B.get(p.params.hookPath)),f=w.create();return($,d)=>(r(),a(I,null,{navbar:s(()=>[e(t)?(r(),a(e(D),{key:0,title:e(t).title,onBack:y},{footer:s(()=>[l(e(R),{"active-key":o.value,"onUpdate:activeKey":d[0]||(d[0]=u=>o.value=u)},{default:s(()=>[l(e(_),{key:"test",tab:"Test"}),l(e(_),{key:"settings",tab:"Settings"})]),_:1},8,["active-key"])]),extra:s(()=>[l(H,{path:"hooks"}),o.value==="settings"?(r(),a(C,{key:0,model:e(t)},null,8,["model"])):i("",!0)]),_:1},8,["title"])):i("",!0)]),content:s(()=>[e(t)&&o.value==="test"?(r(),a(S,{key:0,ref_key:"tester",ref:c,hook:e(t),"log-service":e(f)},null,8,["hook","log-service"])):i("",!0),e(t)&&o.value==="settings"?(r(),a(T,{key:1,hook:e(t)},null,8,["hook"])):i("",!0)]),footer:s(()=>{var u;return[e(t)&&o.value==="test"?(r(),a(h,{key:0,runtime:"forms","log-service":e(f),onRestart:(u=c.value)==null?void 0:u.runHook},null,8,["log-service","onRestart"])):i("",!0)]}),_:1}))}});export{ie as default};
//# sourceMappingURL=HookEditor.a66fa114.js.map
