import{d as o,b as a,c as r,w as c,b0 as i,u as d,cb as p}from"./registerWidgets.4340e287.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="d1743806-b3b7-44ce-bac4-251d310e8917",t._sentryDebugIdIdentifier="sentry-dbid-d1743806-b3b7-44ce-bac4-251d310e8917")}catch{}})();class f{async get(){return(await fetch("/_editor/api/login")).json()}async create(e){return(await fetch("/_editor/api/login",{method:"POST",headers:{"Content-Type":"application/json"},body:JSON.stringify({token:e})})).json()}async delete(){await fetch("/_editor/api/login",{method:"DELETE"})}}const l=new f,u=o({__name:"DocsButton",props:{path:{}},setup(t){return(e,n)=>{var s;return a(),r(d(p),{class:"docs-button",href:`https://docs.abstra.io/${(s=e.path)!=null?s:""}`,target:"_blank"},{default:c(()=>[i(" Docs ")]),_:1},8,["href"])}}});export{u as _,l};
//# sourceMappingURL=DocsButton.vue_vue_type_script_setup_true_lang.82d53ed3.js.map
