import"./registerWidgets.4340e287.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[e]="d499751a-4d40-4e16-9b8d-2ca86d44da9e",r._sentryDebugIdIdentifier="sentry-dbid-d499751a-4d40-4e16-9b8d-2ca86d44da9e")}catch{}})();class a{static get(e){try{const t=localStorage.getItem(e);return t&&JSON.parse(t)}catch{return null}}static set(e,t){localStorage.setItem(e,JSON.stringify(t))}static pop(e){const t=a.get(e);return a.remove(e),t}static remove(e){localStorage.removeItem(e)}}export{a as S};
//# sourceMappingURL=storage.dfe55847.js.map
